@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -48,7 +48,7 @@ class FieldAction(Action):
             A toolkit control or None.
         """
         field = self.field_type(parent=parent, **self.field_defaults)
-        field._create()
+        field.create()
         field.observe(self.value_updated, "value")
         field.control._field = field
         return field.control
@@ -70,7 +70,7 @@ class FieldAction(Action):
 
         Parameters
         ----------
-        event : ActionEvent instance
+        event : ActionEvent
             The event which triggered the action.
         """
         if self.on_perform is not None:
