@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,10 +8,31 @@
 #
 # Thanks for using Enthought open source!
 
+"""
+
+API for the ``pyface.data_view.value_types`` subpackage.
+
+Value Types
+-----------
+
+- :class:`~.BoolValue`
+- :class:`~.ColorValue`
+- :class:`~.ConstantValue`
+- :class:`~.EditableValue`
+- :class:`~.NoValue`
+- :attr:`~.no_value`
+- :class:`~.FloatValue`
+- :class:`~.IntValue`
+- :class:`~.NumericValue`
+- :class:`~.TextValue`
+
+"""
+
 from .bool_value import BoolValue  # noqa: F401
 from .color_value import ColorValue  # noqa: F401
 from .constant_value import ConstantValue  # noqa: F401
 from .editable_value import EditableValue  # noqa: F401
+from .enum_value import EnumValue  # noqa: F401
 from .no_value import NoValue, no_value  # noqa: F401
 from .numeric_value import FloatValue, IntValue, NumericValue  # noqa: F401
 from .text_value import TextValue  # noqa: F401
