@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,7 +11,7 @@
 """ The interface to system metrics (screen width and height etc). """
 
 
-from traits.api import HasTraits, Int, Interface, Tuple
+from traits.api import HasTraits, Int, Interface, List, Tuple
 
 
 class ISystemMetrics(Interface):
@@ -19,12 +19,15 @@ class ISystemMetrics(Interface):
 
     # 'ISystemMetrics' interface -------------------------------------------
 
-    #: The width of the screen in pixels.
+    #: The width of the main screen in pixels.
     screen_width = Int()
 
-    #: The height of the screen in pixels.
+    #: The height of the main screen in pixels.
     screen_height = Int()
 
+    #: The height and width of each screen in pixels
+    screen_sizes = List(Tuple(Int, Int))
+
     #: Background color of a standard dialog window as a tuple of RGB values
     #: between 0.0 and 1.0.
     # FIXME v3: Why isn't this a traits colour?
