@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,9 +11,21 @@
 """ The implementation of a dialog that displays a message. """
 
 
+# Import the toolkit specific version.
+from .toolkit import toolkit_object
+
+
+MessageDialog = toolkit_object("message_dialog:MessageDialog")
+
+
 # Convenience functions.
 def information(
-    parent, message, title="Information", detail="", informative=""
+    parent,
+    message,
+    title="Information",
+    detail="",
+    informative="",
+    text_format="auto"
 ):
     """ Convenience method to show an information message dialog.
 
@@ -30,6 +42,9 @@ def information(
         "Show details").
     informative : str
         Explanatory text to display along with the message.
+    text_format : str
+        Specifies what text format to use in the resulting message dialog.
+        One of "auto", "plain", or "rich". Only supported on the qt backend.
 
     """
     dialog = MessageDialog(
@@ -39,11 +54,19 @@ def information(
         severity="information",
         detail=detail,
         informative=informative,
+        text_format=text_format,
     )
     dialog.open()
 
 
-def warning(parent, message, title="Warning", detail="", informative=""):
+def warning(
+    parent,
+    message,
+    title="Warning",
+    detail="",
+    informative="",
+    text_format="auto"
+):
     """ Convenience function to show a warning message dialog.
 
     Parameters
@@ -59,6 +82,9 @@ def warning(parent, message, title="Warning", detail="", informative=""):
         "Show details").
     informative : str
         Explanatory text to display along with the message.
+    text_format : str
+        Specifies what text format to use in the resulting message dialog.
+        One of "auto", "plain", or "rich". Only supported on the qt backend.
 
     """
     dialog = MessageDialog(
@@ -68,11 +94,19 @@ def warning(parent, message, title="Warning", detail="", informative=""):
         severity="warning",
         detail=detail,
         informative=informative,
+        text_format=text_format,
     )
     dialog.open()
 
 
-def error(parent, message, title="Error", detail="", informative=""):
+def error(
+    parent,
+    message,
+    title="Error",
+    detail="",
+    informative="",
+    text_format="auto"
+):
     """ Convenience function to show an error message dialog.
 
     Parameters
@@ -88,6 +122,9 @@ def error(parent, message, title="Error", detail="", informative=""):
         "Show details").
     informative : str
         Explanatory text to display along with the message.
+    text_format : str
+        Specifies what text format to use in the resulting message dialog.
+        One of "auto", "plain", or "rich". Only supported on the qt backend.
 
     """
     dialog = MessageDialog(
@@ -97,11 +134,6 @@ def error(parent, message, title="Error", detail="", informative=""):
         severity="error",
         detail=detail,
         informative=informative,
+        text_format=text_format,
     )
     dialog.open()
-
-
-# Import the toolkit specific version.
-from .toolkit import toolkit_object
-
-MessageDialog = toolkit_object("message_dialog:MessageDialog")
