@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,6 +15,12 @@ from . import qt_api
 if qt_api == "pyqt5":
     from PyQt5.QtMultimedia import *
 
+elif qt_api == "pyqt6":
+    from PyQt6.QtMultimedia import *
+
+elif qt_api == "pyside6":
+    from PySide6.QtMultimedia import *
+
 elif qt_api == "pyside2":
     from PySide2.QtMultimedia import *
 
