@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,11 +9,14 @@
 # Thanks for using Enthought open source!
 from . import qt_api
 
-if qt_api == "pyqt":
-    from PyQt4.QtNetwork import *
-
-elif qt_api == "pyqt5":
+if qt_api == "pyqt5":
     from PyQt5.QtNetwork import *
 
+elif qt_api == "pyqt6":
+    from PyQt6.QtNetwork import *
+
+elif qt_api == "pyside6":
+    from PySide6.QtNetwork import *
+
 else:
     from PySide2.QtNetwork import *
