@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,10 +9,7 @@
 # Thanks for using Enthought open source!
 from . import qt_api
 
-if qt_api == "pyqt":
-    from PyQt4.QtOpenGL import *
-
-elif qt_api == "pyqt5":
+if qt_api == "pyqt5":
     from PyQt5.QtOpenGL import *
     from PyQt5.QtWidgets import QOpenGLWidget
 
