@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,9 +9,10 @@
 # Thanks for using Enthought open source!
 
 
-from pyface.action.api import Action, ActionItem, Group
 from traits.api import Any, Instance, List, Property, Str, observe
 
+from pyface.action.api import Action, Group
+
 
 class TaskWindowToggleAction(Action):
     """ An action for activating an application window.
@@ -83,7 +84,7 @@ class TaskWindowToggleGroup(Group):
     def destroy(self):
         """ Called when the group is no longer required.
         """
-        super(TaskWindowToggleGroup, self).destroy()
+        super().destroy()
         if self.application:
             self.application.observe(
                 self._rebuild, "windows.items", remove=True
@@ -94,6 +95,8 @@ class TaskWindowToggleGroup(Group):
     # -------------------------------------------------------------------------
 
     def _get_items(self):
+        from pyface.action.action_item import ActionItem
+
         items = []
         for window in self.application.windows:
             active = window == self.application.active_window
