@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -27,11 +27,11 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
         self.window = Window()
-        self.window._create()
+        self.window.create()
 
     def tearDown(self):
         if self.widget.control is not None:
-            with self.delete_widget(self.widget.control):
+            with self.delete_widget(self.window.control):
                 self.widget.destroy()
 
         if self.window.control is not None:
@@ -43,10 +43,24 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
         GuiTestAssistant.tearDown(self)
 
     def test_lifecycle(self):
-        # test that destroy works
+        # test that create/destroy works
+        self.widget = HeadingText(self.window.control)
+
+        self.assertIsNone(self.widget.control)
+
         with self.event_loop():
-            with self.assertWarns(PendingDeprecationWarning):
-                self.widget = HeadingText(self.window.control)
+            self.widget.create(parent=self.window.control)
+
+        self.assertIsNotNone(self.widget.control)
+
+        with self.event_loop():
+            self.widget.destroy()
+
+    def test_one_stage_create(self):
+        # test that automatic creation works
+        with self.event_loop():
+            with self.assertWarns(DeprecationWarning):
+                self.widget = HeadingText(self.window.control, create=True)
 
         self.assertIsNotNone(self.widget.control)
 
@@ -55,13 +69,13 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
 
     def test_two_stage_create(self):
         # test that create=False works
-        self.widget = HeadingText(create=False)
+        with self.assertWarns(DeprecationWarning):
+            self.widget = HeadingText(create=False)
 
         self.assertIsNone(self.widget.control)
 
         with self.event_loop():
-            self.widget.parent = self.window.control
-            self.widget.create()
+            self.widget.create(parent=self.window.control)
 
         self.assertIsNotNone(self.widget.control)
 
@@ -74,7 +88,6 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
             self.widget = HeadingText(
                 self.window.control,
                 text="Hello",
-                create=False,
             )
             self.widget.create()
 
@@ -88,9 +101,8 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
     def test_image(self):
         # test that image raises a deprecation warning
         with self.event_loop():
-            with self.assertWarns(PendingDeprecationWarning):
+            with self.assertWarns(DeprecationWarning):
                 self.widget = HeadingText(
                     self.window.control,
-                    create=False,
                     image=ImageResource("core.png"),
                 )
