@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,7 +17,7 @@ from ..constant import OK
 from ..toolkit import toolkit_object
 from ..window import Window
 
-is_qt = toolkit_object.toolkit == "qt4"
+is_qt = toolkit_object.toolkit.startswith("qt")
 if is_qt:
     from pyface.qt import qt_api
 
@@ -51,7 +51,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
     def test_create(self):
         # test that creation and destruction works as expected
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -64,7 +64,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         # test that size works as expected
         self.dialog.size = (100, 100)
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -72,17 +72,16 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         # test that position works as expected
         self.dialog.position = (100, 100)
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
     def test_create_parent(self):
         # test that creation and destruction works as expected with a parent
         parent = Window()
-        self.dialog.parent = parent.control
         with self.event_loop():
-            parent._create()
-            self.dialog._create()
+            parent.create(parent.control)
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
             parent.destroy()
@@ -91,7 +90,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works as expected with ok_label
         self.dialog.ok_label = "Sure"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -99,7 +98,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works as expected with message
         self.dialog.message = "This is the message"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -108,7 +107,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.message = "This is the message"
         self.dialog.informative = "This is the additional message"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -118,7 +117,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.informative = "This is the additional message"
         self.dialog.detail = "This is the detail"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -126,7 +125,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works with warning message
         self.dialog.severity = "warning"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -134,7 +133,7 @@ class TestMessageDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works with error message
         self.dialog.severity = "error"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
