@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -20,7 +20,7 @@ no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 
 @unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
-class TestDialog(unittest.TestCase, GuiTestAssistant):
+class TestSplitDialog(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
         self.dialog = SplitDialog()
@@ -35,7 +35,7 @@ class TestDialog(unittest.TestCase, GuiTestAssistant):
     def test_create(self):
         # test that creation and destruction works as expected
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -48,7 +48,7 @@ class TestDialog(unittest.TestCase, GuiTestAssistant):
         # test that horizontal split works
         self.dialog.direction = "horizontal"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -56,7 +56,7 @@ class TestDialog(unittest.TestCase, GuiTestAssistant):
         # test that ratio works
         self.dialog.ratio = 0.25
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -65,6 +65,21 @@ class TestDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.lhs = HeadingText
         self.dialog.rhs = HeadingText
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
+        with self.event_loop():
+            self.dialog.destroy()
+
+    def test_contents_toolkit_control(self):
+        # test that toolkit control contents works
+        def create_toolkit_control(parent):
+            widget = HeadingText(parent)
+            widget.create()
+            return widget.control
+
+        self.dialog.lhs = create_toolkit_control
+        self.dialog.rhs = create_toolkit_control
+        with self.event_loop():
+            self.dialog.create()
+
         with self.event_loop():
             self.dialog.destroy()
