@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,12 +12,25 @@
 import os
 import unittest
 
+# importlib.resources is new in Python 3.7, and importlib.resources.files is
+# new in Python 3.9, so for Python < 3.9 we must rely on the 3rd party
+# importlib_resources package.
+try:
+    from importlib.resources import files
+except ImportError:
+    from importlib_resources import files
+
+try:
+    import PIL.Image
+except ImportError:
+    PIL = None
+
 from traits.api import DefaultValue, HasTraits, TraitError
 from traits.testing.optional_dependencies import numpy as np, requires_numpy
 from traits.testing.api import UnittestTools
 
 from ..color import Color
-from ..i_image_resource import IImageResource
+from ..font import Font
 from ..image_resource import ImageResource
 from ..ui_traits import (
     Border,
@@ -26,12 +39,13 @@ from ..ui_traits import (
     Image,
     Margin,
     PyfaceColor,
+    PyfaceFont,
     image_resource_cache,
     image_bitmap_cache,
 )
 
 
-IMAGE_PATH = os.path.join(os.path.dirname(__file__), "images", "core.png")
+IMAGE_PATH = os.fspath(files("pyface.tests") / "images" / "core.png")
 
 
 class ImageClass(HasTraits):
@@ -44,6 +58,11 @@ class ColorClass(HasTraits):
     color = PyfaceColor()
 
 
+class FontClass(HasTraits):
+
+    font = PyfaceFont()
+
+
 class HasMarginClass(HasTraits):
 
     margin = HasMargin
@@ -82,7 +101,7 @@ class TestImageTrait(unittest.TestCase, UnittestTools):
         from pyface.image_resource import ImageResource
 
         image_class = ImageClass(image="about")
-        im = image_class.image.create_image()
+        image_class.image.create_image()
 
         self.assertIsInstance(image_class.image, ImageResource)
         self.assertEqual(image_class.image.name, "about")
@@ -102,6 +121,27 @@ class TestImageTrait(unittest.TestCase, UnittestTools):
         )
         self.assertEqual(image_class.image._ref.volume_name, "icons")
 
+    @requires_numpy
+    def test_init_array_image(self):
+        from pyface.array_image import ArrayImage
+
+        data = np.full((32, 64, 4), 0xee, dtype='uint8')
+        image = ArrayImage(data)
+        image_class = ImageClass(image=image)
+
+        self.assertIsInstance(image_class.image, ArrayImage)
+        self.assertTrue((image_class.image.data == data).all())
+
+    @unittest.skipIf(PIL is None, "PIL/Pillow is not available")
+    def test_init_pil_image(self):
+        from pyface.pil_image import PILImage
+
+        pil_image = PIL.Image.open(IMAGE_PATH)
+        image = PILImage(pil_image)
+        image_class = ImageClass(image=image)
+
+        self.assertIsInstance(image_class.image, PILImage)
+
 
 class TestMargin(unittest.TestCase):
     def test_defaults(self):
@@ -321,6 +361,134 @@ class TestPyfaceColor(unittest.TestCase):
         self.assertEqual(color_class.color, color)
 
 
+class TestPyfaceFont(unittest.TestCase):
+
+    def test_init(self):
+        trait = PyfaceFont()
+        self.assertEqual(trait.default_value, (Font, (), {}))
+        self.assertEqual(
+            trait.default_value_type,
+            DefaultValue.callable_and_args,
+        )
+
+    def test_init_empty_string(self):
+        trait = PyfaceFont("")
+        self.assertEqual(
+            trait.default_value,
+            (
+                Font,
+                (),
+                {
+                    'family': ["default"],
+                    'size': 12.0,
+                    'weight': "normal",
+                    'stretch': 100,
+                    'style': "normal",
+                    'variants': set(),
+                    'decorations': set(),
+                },
+            )
+        )
+
+    def test_init_typical_string(self):
+        trait = PyfaceFont(
+            "10 pt bold condensed italic underline Helvetica sans-serif")
+        self.assertEqual(
+            trait.default_value,
+            (
+                Font,
+                (),
+                {
+                    'family': ["helvetica", "sans-serif"],
+                    'size': 10.0,
+                    'weight': "bold",
+                    'stretch': 75.0,
+                    'style': "italic",
+                    'variants': set(),
+                    'decorations': {"underline"},
+                },
+            )
+        )
+
+    def test_init_font(self):
+        font = Font(
+            family=["helvetica", "sans-serif"],
+            size=10.0,
+            weight="bold",
+            stretch=75.0,
+            style="italic",
+            variants=set(),
+            decorations={"underline"},
+        )
+        trait = PyfaceFont(font)
+        self.assertEqual(
+            trait.default_value,
+            (
+                Font,
+                (),
+                {
+                    'family': ["helvetica", "sans-serif"],
+                    'size': 10.0,
+                    'weight': "bold",
+                    'stretch': 75.0,
+                    'style': "italic",
+                    'variants': set(),
+                    'decorations': {"underline"},
+                },
+            )
+        )
+
+    def test_init_invalid(self):
+        with self.assertRaises(ValueError):
+            PyfaceFont(0)
+
+    def test_set_empty_string(self):
+        font_class = FontClass()
+        font_class.font = ""
+        self.assertFontEqual(font_class.font, Font())
+
+    def test_set_typical_string(self):
+        font_class = FontClass()
+        font_class.font = "10 pt bold condensed italic underline Helvetica sans-serif"  # noqa: E501
+        self.assertFontEqual(
+            font_class.font,
+            Font(
+                family=["helvetica", "sans-serif"],
+                size=10.0,
+                weight="bold",
+                stretch=75.0,
+                style="italic",
+                variants=set(),
+                decorations={"underline"},
+            ),
+        )
+
+    def test_set_font(self):
+        font_class = FontClass()
+        font = Font(
+            family=["helvetica", "sans-serif"],
+            size=10.0,
+            weight="bold",
+            stretch=75.0,
+            style="italic",
+            variants=set(),
+            decorations={"underline"},
+        )
+        font_class.font = font
+        self.assertIs(font_class.font, font)
+
+    def test_set_failure(self):
+        font_class = FontClass()
+
+        with self.assertRaises(TraitError):
+            font_class.font = None
+
+    def assertFontEqual(self, font1, font2):
+        state1 = font1.trait_get(transient=lambda x: not x)
+        state2 = font2.trait_get(transient=lambda x: not x)
+        self.assertEqual(state1, state2)
+
+
 class TestHasMargin(unittest.TestCase, UnittestTools):
     def test_defaults(self):
         has_margin = HasMarginClass()
