@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -22,38 +22,39 @@ from traits.api import (
     Bool,
     Callable,
     Dict,
-    Either,
     HasTraits,
     Instance,
     Int,
     List,
     Str,
     Type,
+    Union,
 )
-
+from traits.observation.api import match
 
 from .grid_model import GridColumn, GridModel, GridSortEvent
 from .trait_grid_cell_adapter import TraitGridCellAdapter
 
+
 # The classes below are part of the table specification.
 class TraitGridColumn(GridColumn):
     """ Structure for holding column specifications in a TraitGridModel. """
 
     # The trait name for this column. This takes precedence over method
-    name = Either(None, Str)
+    name = Union(None, Str)
 
     # A method name to call to get the value for this column
-    method = Either(None, Str)
+    method = Union(None, Str)
 
     # A method to be used to sort on this column
     sorter = Callable
 
     # A dictionary of formats for the display of different types. If it is
     # defined as a callable, then that callable must accept a single argument.
-    formats = Dict(Type, Either(Str, Callable))
+    formats = Dict(Type, Union(Str, Callable))
 
     # A name to designate the type of this column
-    typename = Either(None, Str)
+    typename = Union(None, Str)
     # note: context menus should go in here as well? but we need
     #       more info than we have available at this point
 
@@ -67,7 +68,7 @@ class TraitGridSelection(HasTraits):
     obj = Instance(HasTraits)
 
     # The specific trait selected on the object
-    trait_name = Either(None, Str)
+    trait_name = Union(None, Str)
 
 
 # The meat.
@@ -83,10 +84,10 @@ class TraitGridModel(GridModel):
     data = List(Any)
 
     # The column definitions
-    columns = Either(None, List(Either(None, Str, Instance(TraitGridColumn))))
+    columns = Union(None, List(Union(None, Str, Instance(TraitGridColumn))))
 
     # The trait to look at to get the row name
-    row_name_trait = Either(None, Str)
+    row_name_trait = Union(None, Str)
 
     # Allow column sorting?
     allow_column_sort = Bool(True)
@@ -102,7 +103,7 @@ class TraitGridModel(GridModel):
         """ Create a TraitGridModel object. """
 
         # Base class constructor
-        super(TraitGridModel, self).__init__(**traits)
+        super().__init__(**traits)
 
         # if no columns are pass in then create the list of names
         # from the first trait in the list. if the list is empty,
@@ -640,7 +641,7 @@ class TraitGridModel(GridModel):
 
     def __get_column_typename(self, col):
 
-        name = column = self.__get_column(col)
+        column = self.__get_column(col)
         typename = None
         if isinstance(column, TraitGridColumn):
             typename = column.typename
@@ -685,7 +686,9 @@ class TraitGridModel(GridModel):
         if list is not None:
             for item in list:
                 item.observe(
-                    self._on_contained_trait_changed, remove=remove
+                    self._on_contained_trait_changed,
+                    match(lambda name, trait: True),
+                    remove=remove
                 )
 
     def __manage_column_listeners(self, collist, remove=False):
@@ -694,5 +697,7 @@ class TraitGridModel(GridModel):
             for col in collist:
                 if isinstance(col, TraitGridColumn):
                     col.observe(
-                        self._on_columns_changed, remove=remove
+                        self._on_columns_changed,
+                        match(lambda name, trait: True),
+                        remove=remove,
                     )
