@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -36,7 +36,7 @@ class EditorManager(HasTraits):
     def __init__(self, **traits):
         """ Constructor. """
 
-        super(EditorManager, self).__init__(**traits)
+        super().__init__(**traits)
 
         # A mapping from editor to editor kind (the factory that created them).
         self._editor_to_kind_map = weakref.WeakKeyDictionary()
