@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,7 +8,10 @@
 #
 # Thanks for using Enthought open source!
 
-import os, wx
+import os
+
+import wx
+
 from traits.util.resource import get_path
 
 
